import unittest
from unittest.mock import patch

from chromie import config


class TestConfig(unittest.TestCase):
    def test_from_file(self):
        pass

    def test_set_values(self):
        pass

    def test_file_does_not_exist(self):
        pass


if __name__ == "__main__":
    unittest.main()
